==> vue-tsc-0.0.26.tgz: package/README.md <==
# vue-tsc

`vue-tsc --noEmit && vite build`

Vue 3 command line Type-Checking tool base on IDE plugin [Volar](https://github.com/johnsoncodehk/volar).

Features:

- [x] Type-Checking with `--noEmit`
- [ ] Use released LSP module
- [ ] Watch mode support

## Navigation

> Have a Vue TypeScript question?

Please ask to [Vue Discord](https://discord.com/channels/325477692906536972/331999220125138944).

> If Type-Checking result unexpected, and the result consistent with Volar.

Please open issue to [Volar Issues](https://github.com/johnsoncodehk/volar/issues).

> If Type-Checking result inconsistent with Volar, and your vue-tsc included Volar version is
> <a href="https://marketplace.visualstudio.com/items?itemName=johnsoncodehk.volar">
>   <img src="https://vsmarketplacebadge.apphb.com/version-short/johnsoncodehk.volar.svg?label=%20&style=flat-square&color=42b883">
> </a>.

> If Command-line tool works unexpected.

Please open issue to this repo.

> Other problems?

Please ask to [Volar Discord](https://discord.gg/5bnSSSSBbK).

## Versions

| vue-tsc | TypeScript | Volar   |
|---------|------------|---------|
| 0.0.26  | 4.2.3      | 0.24.6  |
| 0.0.25  | 4.2.3      | 0.24.1  |
| 0.0.24  | 4.2.3      | 0.24.0  |
| 0.0.22  | 4.2.3      | 0.23.7  |
| 0.0.21  | 4.2.3      | 0.23.4  |
| 0.0.20  | 4.2.3      | 0.23.2  |
| 0.0.19  | 4.2.3      | 0.23.0  |
| 0.0.18  | 4.2.3      | 0.22.26 |
| 0.0.17  | 4.2.3      | 0.22.24 |
| 0.0.16  | 4.2.3      | 0.22.23 |
| 0.0.15  | 4.2.3      | 0.22.22 |
| 0.0.14  | 4.2.3      | 0.22.17 |
| 0.0.13  | 4.2.3      | 0.22.16 |
| 0.0.12  | 4.2.3      | 0.22.14 |
| 0.0.11  | 4.2.3      | 0.22.12 |
| 0.0.9   | 4.2.3      | 0.22.11 |
| 0.0.8   | 4.2.2      | 0.22.4  |
| 0.0.7   | 4.2.2      | 0.21.20 |

==> vue-tsc-0.1.0.tgz: package/README.md <==
# vue-tsc

`vue-tsc --noEmit && vite build`

Vue 3 command line Type-Checking tool base on IDE plugin [Volar](https://github.com/johnsoncodehk/volar).

Features:

- [x] Type-Checking with `--noEmit`
- [x] Use released LSP module
- [ ] Watch mode support

## Navigation

> Have a Vue TypeScript question?

Please ask to [Vue Discord](https://discord.com/channels/325477692906536972/331999220125138944).

> If Type-Checking result unexpected, and the result consistent with Volar.

Please open issue to [Volar Issues](https://github.com/johnsoncodehk/volar/issues).

> If Type-Checking result inconsistent with Volar, and your vue-tsc included Volar version is
> <a href="https://marketplace.visualstudio.com/items?itemName=johnsoncodehk.volar">
>   <img src="https://vsmarketplacebadge.apphb.com/version-short/johnsoncodehk.volar.svg?label=%20&style=flat-square&color=42b883">
> </a>.

> If Command-line tool works unexpected.

Please open issue to this repo.

> Other problems?

Please ask to [Volar Discord](https://discord.gg/5bnSSSSBbK).

## Versions

| vue-tsc | TypeScript | Volar   |
|---------|------------|---------|
| 0.0.26  | 4.2.3      | 0.24.6  |
| 0.0.25  | 4.2.3      | 0.24.1  |
| 0.0.24  | 4.2.3      | 0.24.0  |
| 0.0.22  | 4.2.3      | 0.23.7  |
| 0.0.21  | 4.2.3      | 0.23.4  |
| 0.0.20  | 4.2.3      | 0.23.2  |
| 0.0.19  | 4.2.3      | 0.23.0  |
| 0.0.18  | 4.2.3      | 0.22.26 |
| 0.0.17  | 4.2.3      | 0.22.24 |
| 0.0.16  | 4.2.3      | 0.22.23 |
| 0.0.15  | 4.2.3      | 0.22.22 |
| 0.0.14  | 4.2.3      | 0.22.17 |
| 0.0.13  | 4.2.3      | 0.22.16 |
| 0.0.12  | 4.2.3      | 0.22.14 |
| 0.0.11  | 4.2.3      | 0.22.12 |
| 0.0.9   | 4.2.3      | 0.22.11 |
| 0.0.8   | 4.2.2      | 0.22.4  |
| 0.0.7   | 4.2.2      | 0.21.20 |
